@@ -1,5 +1,5 @@
 from collections.abc import Callable, Iterable
-from typing import Any, TYPE_CHECKING, cast
+from typing import TYPE_CHECKING, Any, cast
 from uuid import UUID
 
 from pycrdt import Map
@@ -7,6 +7,7 @@ from pycrdt import Map
 if TYPE_CHECKING:
     from .db import DB
 
+
 class Mixin:
     _uuid: str
     _map: Map
