@@ -4,7 +4,7 @@ from dataclasses import dataclass
 from datetime import datetime
 from functools import partial
 from json import dumps
-from typing import Any, TYPE_CHECKING
+from typing import TYPE_CHECKING, Any
 
 from pycrdt import Map
 
@@ -35,7 +35,7 @@ class Event(Mixin):
         if not isinstance(other, Event):
             return NotImplemented
 
-        return self._uuid == other._uuid
+        return self.to_dict() == other.to_dict()
 
     def __repr__(self) -> str:
         return dumps(self.to_dict())
@@ -46,13 +46,19 @@ class Event(Mixin):
     def _get(self, name: str) -> Any:
         self._check_deleted()
         value = self._map[name]
-        model = EventModel.__pydantic_validator__.validate_assignment(EventModel.model_construct(), name, value)
+        model = EventModel.__pydantic_validator__.validate_assignment(
+            EventModel.model_construct(), name, value
+        )
         return getattr(model, name)
 
-    def _set(self, name: str, value: Any, func: Callable[[Any], Any] | None = None) -> None:
+    def _set(
+        self, name: str, value: Any, func: Callable[[Any], Any] | None = None
+    ) -> None:
         with self._db.transaction():
             self._check_deleted()
-            model = EventModel.__pydantic_validator__.validate_assignment(EventModel.model_construct(), name, value)
+            model = EventModel.__pydantic_validator__.validate_assignment(
+                EventModel.model_construct(), name, value
+            )
             val = getattr(model, name)
             if func is not None:
                 val = func(val)
@@ -60,29 +66,37 @@ class Event(Mixin):
 
     def _on_change(self, name: str, callback: Callable[[Any], None]) -> None:
         self._check_deleted()
-        self._db._event_change_callbacks[self._uuid][name].append(partial(self._callback, callback))
+        self._db._event_change_callbacks[self._uuid][name].append(
+            partial(self._callback, callback)
+        )
 
     def _on_add(self, field: str, callback: Callable[[Any], None]) -> None:
         self._check_deleted()
-        self._db._event_change_callbacks[self._uuid][f"add_{field}"].append(partial(self._callback, callback))
+        self._db._event_change_callbacks[self._uuid][f"add_{field}"].append(
+            partial(self._callback, callback)
+        )
 
     def _on_remove(self, field: str, callback: Callable[[list[str]], None]) -> None:
         self._check_deleted()
-        self._db._event_change_callbacks[self._uuid][f"remove_{field}"].append(partial(self._callback, callback))
+        self._db._event_change_callbacks[self._uuid][f"remove_{field}"].append(
+            partial(self._callback, callback)
+        )
 
     @classmethod
     def new(cls, model: EventModel, db: "DB") -> Self:
         uuid = str(model.uuid)
-        map = Map(dict(
-            uuid=uuid,
-            start=str(model.start),
-            stop=str(model.stop),
-            author=model.author,
-            tags=Map({val: True for val in model.tags}),
-            products=Map({val: True for val in model.products}),
-            rating=model.rating,
-            attributes=Map(model.attributes),
-        ))
+        map = Map(
+            dict(
+                uuid=uuid,
+                start=str(model.start),
+                stop=str(model.stop),
+                author=model.author,
+                tags=Map({val: True for val in model.tags}),
+                products=Map({val: True for val in model.products}),
+                rating=model.rating,
+                attributes=Map(model.attributes),
+            )
+        )
         self = cls(uuid, map, db)
         db._events[uuid] = self
         return self
@@ -109,8 +123,8 @@ class Event(Mixin):
         self._check_deleted()
         dct = self._map.to_py()
         assert dct is not None
-        dct["tags"] = list(dct["tags"].keys())
-        dct["products"] = list(dct["products"].keys())
+        dct["tags"] = list(sorted(dct["tags"].keys()))
+        dct["products"] = list(sorted(dct["products"].keys()))
         dct["attributes"] = dict(sorted(dct["attributes"].items()))
         return dict(sorted(dct.items()))
 
@@ -141,6 +155,28 @@ class Event(Mixin):
         """
         self._on_change("stop", callback)
 
+    def on_change_range(self, callback: Callable[[datetime, datetime], None]) -> None:
+        """
+        Registers a callback to be called when the event start and/or stop dates change.
+
+        Args:
+            callback: The callback to call with the new range.
+        """
+        range: list[None | datetime] = [None, None]
+
+        def callback_start(start: datetime) -> None:
+            if range != [start, self.stop]:
+                range[0], range[1] = start, self.stop
+                callback(start, self.stop)
+
+        def callback_stop(stop: datetime) -> None:
+            if range != [self.start, stop]:
+                range[0], range[1] = self.start, stop
+                callback(self.start, stop)
+
+        self._on_change("start", callback_start)
+        self._on_change("stop", callback_stop)
+
     def on_change_rating(self, callback: Callable[[Any], None]) -> None:
         """
         Registers a callback to be called when the event rating changes.
@@ -158,7 +194,9 @@ class Event(Mixin):
             callback: The callback to call.
         """
         self._check_deleted()
-        self._db._event_delete_callbacks[self._uuid].append(partial(self._callback, callback))
+        self._db._event_delete_callbacks[self._uuid].append(
+            partial(self._callback, callback)
+        )
 
     def delete(self):
         """
@@ -204,6 +242,25 @@ class Event(Mixin):
         """
         self._set("stop", value, str)
 
+    @property
+    def range(self) -> tuple[datetime, datetime]:
+        """
+        Returns:
+            The start and stop dates of the event.
+        """
+        return self._get("start"), self._get("stop")
+
+    @range.setter
+    def range(self, value: tuple[datetime, datetime]) -> None:
+        """
+        Args:
+            value: The start and stop dates of the event to set.
+        """
+        with self._db.transaction():
+            start, stop = value
+            self._set("start", start, str)
+            self._set("stop", stop, str)
+
     @property
     def rating(self) -> int:
         """
